class CfgAmmo
{
	class RocketBase;
	class R_Hydra_HE : RocketBase
	{
		timeToLive = 60;
		maxSpeed = 900;
		thrustTime = 1.070000; // Mk 66 MOD 4 motor
		thrust = 714;          // 1515 lb-s impulse, 22.95 lb, 7 lb propellant
		sideAirFriction = 0.200000;
	};
	class R_57mm_HE : RocketBase
	{
		timeToLive = 60;
		maxSpeed = 1000;
		thrustTime = 1.100000;
		thrust = 700;
		sideAirFriction = 0.150000;
	};
	class R_80mm_HE : RocketBase
	{
		timeToLive = 60;
		maxSpeed = 750;
		thrustTime = 1.000000;
		thrust = 610;
		sideAirFriction = 0.220000;
	};
	class R_S8T_AT : RocketBase
	{
		timeToLive = 60;
		maxSpeed = 600;
		thrustTime = 1.000000;
		thrust = 500;
		sideAirFriction = 0.220000;
	};
	class R_M136_AT : RocketBase
	{
		timeToLive = 10.000000;
		maxSpeed = 285;
		sideAirFriction = 0.500000;
		initTime = 0;
		thrustTime = 0.10000;
		thrust = 0.1;
	};
	class R_PG7V_AT : RocketBase
	{
		timeToLive = 4.500000;
		maxSpeed = 295;
		sideAirFriction = 0.500000;
		initTime = 0.1;
		thrustTime = 1.0;
		thrust = 280;
	};
	class R_PG7VR_AT : R_PG7V_AT
	{
		maxSpeed = 200;
		initTime = 0.15;
		thrust = 165;
	};
	class MissileBase;
	// I don't know what the maneuverability variables really mean, but these are my guesses:
	//		maneuvrability:  maximum lateral acceleration (in Gs?)
	//		trackOversteer:  scalar for lateral acceleration at any point in time, i.e. latax = (maneuvrability) max ((angle error) * someconstant * trackOversteer)
	//		trackLead:		 0 = track current target location; 1 = track predicted target location

	class M_Stinger_AA : MissileBase
	{
		// MANPADs should be impact fused, but that's not possible in ArmA
		hit = 66;
		indirectHit = 45;          // I really wish I could get rid of the prox. fuse
		indirectHitRange = 7;
		timeToLive = 17;
		maneuvrability = 22;
		simulationStep = 0.002000;
		sideAirFriction = 0.750000;// Lots of drag to simulate boost-sustain motor.
		trackOversteer = 1;
		trackLead = 0;
		maxSpeed = 750;            // used only for AI purposes, unfortunately, and useless here
		initTime = 0.200000;
		thrustTime = 6.500000;     // ~2s boost, sustain to 6.5s?
		thrust = 850;              // should sustain ~750 m/s
		deflecting = 0;
	};
	class M_Strela_AA : MissileBase
	{
		// Listed as an old Strela-2 in game, so that's what it's gonna be
		hit = 50;                  // the tiny 2.5 lb warhead should probably do less damage than this...
		indirectHit = 40;
		indirectHitRange = 7;
		timeToLive = 13;
		maneuvrability = 12;
		simulationStep = 0.002000;
		sideAirFriction = 0.750000;
		trackOversteer = 1;
		trackLead = 0;
		maxSpeed = 500;
		initTime = 0.215000;       // 6m distance at 28m/s, according to Janes
		thrustTime = 7.000000;     // should be close enough
		thrust = 400;              // should sustain ~500 m/s
		deflecting = 0;
	};
	class M_Sidewinder_AA : MissileBase
	{
		hit = 200;                 // default
		indirectHit = 85;          // it should only take one
		indirectHitRange = 10;
		timeToLive = 35;
		maneuvrability = 40;       // AIM-9X deserves a stupidly high maneuverability
		simulationStep = 0.002000;
		sideAirFriction = 0.200000;
		trackOversteer = 1;
		trackLead = 1;             // AIM-9X is all-aspect, lead pursuit
		maxSpeed = 850;
		initTime = 0;              // Sidewinders thrust off the rail, duh.
		thrustTime = 5.000000;     // Falcon 4.0 uses 5s pure boost for AIM-9M and AIM-9X
		thrust = 156;              //  with 12610 lb-s of impulse, an average 16G.  (189 lb total weight, 60 lb propellant)
	};
	class M_R73_AA  : MissileBase
	{
		hit = 160;                 // Has 16 lb warhead to AIM-9's 20 lb.  Default was hit=50, less than a stinger.
		indirectHit = 70;
		indirectHitRange = 9;
		timeToLive = 60;           // R-73E has a self-destruct now, I think
		maneuvrability = 45;       // R-73 is vectored-thrust, like the AIM-9X
		simulationStep = 0.002000;
		sideAirFriction = 0.200000;
		trackOversteer = 1;
		trackLead = 1;
		maxSpeed = 2000;
		initTime = 0;
		thrustTime = 5.0;          // Should be 2-stage boost-boost for a total 6.8 seconds.  No way to simulate that.
		thrust = 155;              // ~15000 lb-s impulse (231 lb, 80 lb propellant)
	};
	class M_Javelin_AT : MissileBase
	{
		hit = 700;                 // 700mm RHA -- normal CE penalty not applied because it's top-attack
		indirectHit = 10;
		indirectHitRange = 5;
		timeToLive = 30;
		maneuvrability = 6;        // Reaches maximum direct fire height on every shot. Minimum range ~350 m, though.
		simulationStep = 0.010000;
		sideAirFriction = 0.100000;
		trackOversteer = 2;
		trackLead = 1;
		maxSpeed = 430;
		initTime = 0.300000;
		thrustTime = 5.000000;     // Has a sustain motor, of some length
		thrust = 125;
		deflecting = 0;
	};
	class M_AT5_AT : MissileBase // 9M113 Konkurs
	{
		// ArmA's ATGMS follow a target 1.5 km in front of your sights.
		// You will not hit a moving target at ranges less than 1.5 km no matter what,
		// and you will not hit any target at a range greater than 1.5 km no matter what.
		// This needs to be scripted to work.
		hit = 450;                  // 650mm RHA
		indirectHit = 10;
		indirectHitRange = 5;
		timeToLive = 25; // supposed to be 25s to 4000m max range
		maneuvrability = 10;
		simulationStep = 0.005000;
		sideAirFriction = 0.050000;
		airFriction = -0.000020;
		manualControl = 1;
		maxControlRange = 4000;
		trackOversteer = 2.5;
		trackLead = 1;
		maxSpeed = 208;             // someone at BIS must think this limits maximum speed?  This thing had way too much thrust.
		initTime = 0.25;
		thrustTime = 1.500000;
		thrust = 115;
		deflecting = 0;
	};
	class M_TOW_AT : MissileBase // TOW-2A
	{
		hit = 700;                  // 1000mm RHA.  Probably an overestimate.
		indirectHit = 10;
		indirectHitRange = 5;
		timeToLive = 23;            // supposed to be 23s to 3750m max range
		maneuvrability = 10;
		simulationStep = 0.005000;
		sideAirFriction = 0.050000;
		airFriction = -0.000020;    // should be 150 m/s at 3 km, 120 m/s at 3.75 km
		manualControl = 1;
		maxControlRange = 3750;     // according to manual
		trackOversteer = 1.5;
		trackLead = 1;
		maxSpeed = 323;             // from fm3-22-1
		initTime = 0.151;           // from fm-23-1
		thrustTime = 1.450000;      // from fm3-22-1
		thrust = 191;
		deflecting = 0;
	};
	class M_Hellfire_AT : MissileBase
	{
		hit = 800;
		indirectHit = 30;
		indirectHitRange = 5;
		timeToLive = 20;
		maneuvrability = 13;
		simulationStep = 0.010000;
		sideAirFriction = 0.200000;
		maxControlRange = 8000;
		irLock = 1;
		laserLock = 1;
		trackOversteer = 1;
		trackLead = 1;
		maxSpeed = 425;
		initTime = 0;  // Launched from the rail
		thrustTime = 3.250000;
		thrust = 130;  // ~4200 lb-s impulse, pure boost
	};
	class M_Vikhr_AT : MissileBase
	{
		hit = 800;
		indirectHit = 30;
		indirectHitRange = 5;
		timeToLive = 120; // no self-destruct
		maneuvrability = 11;
		simulationStep = 0.002000;
		sideAirFriction = 0.200000;
		irLock = 1;
		laserLock = 0;
		manualControl = 1;  // this doesn't work from a helicopter?  It's defined by default...
		maxControlRange = 10000;
		trackOversteer = 2;
		trackLead = 1;
		maxSpeed = 600;
		initTime = 0;
		thrustTime = 4.000000;
		thrust = 260;
	};
	class M_Maverick_AT  : MissileBase
	{
		hit = 1200;                // it's a lot bigger than a Hellfire
		indirectHit = 50;
		indirectHitRange = 10;
		timeToLive = 120;
		maneuvrability = 10;
		simulationStep = 0.010000;
		sideAirFriction = 0.200000;
		irLock = 1;
		trackOversteer = 1;
		trackLead = 1;
		maxSpeed = 300;
		initTime = 0.150000;
		thrustTime = 2.000000;    // 0.5s boost, 3.5s sustain.  No good way to simulate that.
		thrust = 141;             // 10,000 lbs (average 22.5G) vacuum thrust in boost, 2000 lbs (average 5G) in sustain
	};
	class M_Ch29_AT  : MissileBase
	{
        // This thing is silly.  It's made for killing heavy bunkers, not tanks.
        timeToLive = 120;
		hit = 7000;
		indirectHit = 1000;
		indirectHitRange = 12;       // it's also got a 700 lb warhead.
		irLock = 1;
		laserLock = 1;               // lets make it a Kh-29L, since that one has a sensible range
		maneuvrability = 8;          // It's 1500 lbs for Pete's sakes, and has a 5-8 m CEP
		simulationStep = 0.010000;
		sideAirFriction = 0.300000;
		trackOversteer = 1;          // supposed to climb to 5 km and dive?
		trackLead = 0.000000;
		maxSpeed = 805;              // the Russkies doth exaggerate too much, methinks
		initTime = 0.800000;         // 3 m drop distance
		thrustTime = 2.000000;       // boost-sustain, total 3.2 seconds?
		thrust = 150;                // 51,500 lbs of boost thrust?
		CraterEffects = "BombCrater";
		explosionEffects = "BombExplosion";
	};
	class LaserBombCore ;
	class Bo_GBU12_LGB : LaserBombCore
	{
		hit = 2500;
		indirectHit = 350;
		indirectHitRange = 13;
		trackOversteer = 10;
		trackLead = 0.000000;
		maneuvrability = 20; // needs high maneuverability because the guidance logic is shit
		sideAirFriction = 0.100000;
		airFriction = -0.000050; // but this helps a little bit
	};
};